Package: deBif
Type: Package
Title: Bifurcation Analysis of Ordinary Differential Equation Systems
Version: 0.1.8
Authors@R: c(person("Andre M.", "de Roos", email = "A.M.deRoos@uva.nl", role = c("aut", "cre")))
Description: Shiny application that performs bifurcation and phaseplane analysis of systems of ordinary 
    differential equations. The package allows for computation of equilibrium curves as a function of 
    a single free parameter, detection of transcritical, saddle-node and hopf bifurcation points along 
    these curves, and computation of curves representing these transcritical, saddle-node and hopf 
    bifurcation points as a function of two free parameters. The shiny-based GUI allows visualization 
    of the results in both 2D- and 3D-plots. The implemented methods for solution localisation and curve
    continuation are based on the book "Elements of applied bifurcation theory" (Kuznetsov, Y. A., 1995;
    ISBN: 0-387-94418-4).
License: GPL-3
Encoding: UTF-8
NeedsCompilation: yes
Imports: graphics, deSolve (>= 1.3), rootSolve (>= 1.8), rstudioapi (>=
        0.13), shiny (>= 1.7), shinyjs (>= 2.1), shinydashboard (>=
        0.7), shinydashboardPlus (>= 2.0)
Suggests: knitr, R.rsp, rmarkdown
RoxygenNote: 7.2.3
VignetteBuilder: R.rsp
Depends: R (>= 4.2)
Packaged: 2023-12-04 16:52:40 UTC; andre
Author: Andre M. de Roos [aut, cre]
Maintainer: Andre M. de Roos <A.M.deRoos@uva.nl>
Repository: CRAN
Date/Publication: 2023-12-04 17:20:06 UTC
Built: R 4.2.3; aarch64-apple-darwin20; 2023-12-04 19:17:35 UTC; unix
Archs: deBif.so.dSYM
