# Generated by roxygen2: do not edit by hand

export(bifurcation)
export(deBifExample)
export(deBifHelp)
export(deBifReset)
export(phaseplane)
import(deSolve)
import(rootSolve)
import(shiny)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,trans3d)
importFrom(graphics,axTicks)
importFrom(graphics,axis)
importFrom(graphics,contour)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,persp)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(rstudioapi,viewer)
importFrom(shinydashboard,box)
importFrom(shinydashboard,dashboardBody)
importFrom(shinydashboard,menuItem)
importFrom(shinydashboard,sidebarMenu)
importFrom(shinydashboardPlus,controlbarItem)
importFrom(shinydashboardPlus,controlbarMenu)
importFrom(shinydashboardPlus,dashboardControlbar)
importFrom(shinydashboardPlus,dashboardHeader)
importFrom(shinydashboardPlus,dashboardPage)
importFrom(shinydashboardPlus,dashboardSidebar)
importFrom(shinyjs,click)
importFrom(shinyjs,html)
importFrom(shinyjs,removeClass)
importFrom(shinyjs,useShinyjs)
importFrom(stats,setNames)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(utils,browseURL)
importFrom(utils,capture.output)
importFrom(utils,unzip)
useDynLib(deBif)
